@@ -22,13 +22,6 @@ require_relative '../test_helper'
 class UsersControllerTest < Redmine::ControllerTest
   include Redmine::I18n
 
-  fixtures :users, :user_preferences, :email_addresses, :projects, :members, :member_roles, :roles,
-           :custom_fields, :custom_values, :groups_users,
-           :auth_sources,
-           :enabled_modules,
-           :issues, :issue_statuses,
-           :trackers
-
   def setup
     User.current = nil
     @request.session[:user_id] = 1 # admin
